@@ -103,26 +103,20 @@ class KNativeConsumer(threading.Thread):
         print("**** Print the Messages ****")
         
         try:
-            self.consumer.subscribe(self.consumer.topics)
-            running = True
-
-            while running:
-                msg = self.consumer.poll(timeout_ms=1.0)
-                if msg is None: continue
-
-                if msg.error():
-                    # Errors are typically temporary, print error and continue.
-                    print("Consumer error: {}".format(msg.error()))
-                    continue
-
-                print('consumed: {}'.format(msg.value()))
+            self.consumer.subscribe([self.topics])
+            self.consumer.assign([self.topics])
+            for message in self.consumer:
+                print("topic={} partition={} offset={} key={} value={}".format(message.topic,
+                                                                        message.partition,
+                                                                        message.offset,
+                                                                        message.key,
+                                                                        message.value))
+                print('consumed: {}'.format(message.value()))
         except Exception as ex:
                 print("Inexception")
-                print("Exception while creating consumer - {}".format(ex))
-                self.logger.error(f'Kafka Eexception {ex}')
-                self.logger.error("Houston, we have a %s", "major problem", exc_info=1)
-
-
+                print("Exception while getting the message - {}".format(ex))
+                self.logger.error(f'Kafka Exception {ex}')
+                self.logger.error("We have a %s", "major problem. We got an exception!", exc_info=1)
 
     def getMetric(self):
         for p in self.consumer.partitions_for_topic(self.topics):
@@ -135,8 +129,10 @@ class KNativeConsumer(threading.Thread):
                 latest_offset = v
             print("committed_offset")
             print(committed_offset)
+            self.logger.error(committed_offset)
             print("latest offset")
             print(latest_offset)
+            self.logger.error(latest_offset)
             print("lag")
             print(latest_offset - committed_offset)
 
